@@ -25,6 +25,7 @@
 #include "panel-stock-icons.h"
 #include "panel-action-protocol.h"
 #include "panel-lockdown.h"
+#include "panel-icon-names.h"
 #include "xstuff.h"
 
 #include "nothing.cP"
@@ -33,8 +34,6 @@
 GSList *panels = NULL;
 GSList *panel_list = NULL;
 
-GtkTooltips *panel_tooltips = NULL;
-
 static char *deprecated_profile;
 
 static const GOptionEntry options[] = {
@@ -64,15 +63,13 @@ main (int argc, char **argv)
 				      GNOME_PROGRAM_STANDARD_PROPERTIES,
 				      NULL);
 
-	gtk_window_set_default_icon_name ("gnome-panel");
+	gtk_window_set_default_icon_name (PANEL_ICON_PANEL);
 
 	if (!panel_shell_register ())
 		return -1;
 
 	gnome_authentication_manager_init ();
 
-	panel_tooltips = gtk_tooltips_new ();
-
 	panel_action_protocol_init ();
 	panel_multiscreen_init ();
 	panel_init_stock_icons_and_items ();
